// Copyright (c) 2021 BEAN
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
"use strict";

var _textlintRuleHelper = require("textlint-rule-helper");

var japaneseRegExp = /(?:[々〇〻\u3400-\u4DBF\u4E00-\u9FFF\uF900-\uFAFF]|[\uD840-\uD87F][\uDC00-\uDFFF]|[ぁ-んァ-ヶ])/;
var badComma = /[、\,]/;
var errorMessage = "読点が「，」ではありません。";

var reporter = function reporter(context) {
  var {
    Syntax,
    RuleError,
    report,
    fixer,
    getSource
  } = context;
  var ruleHelper = new _textlintRuleHelper.RuleHelper(context);
  return {
    [Syntax.Str](node) {
      if (ruleHelper.isChildNode(node, [Syntax.Link, Syntax.Image, Syntax.BlockQuote, Syntax.Emphasis])) {
        return;
      }

      var targetText = getSource(node);

      if (!japaneseRegExp.test(targetText)) {
        return;
      }

      var validationResults = validateBadComma(targetText, badComma);
      validationResults.forEach(result => {
        if (!result.valid && result.index != undefined) {
          var ruleError = new RuleError(errorMessage, {
            index: result.index,
            fix: fixer.replaceTextRange([result.index, result.index + 1], "，")
          });
          report(node, ruleError);
        }
      });
    }

  };
};
/**
 * 
 * @param text Text for validation
 * @param badComma Regular expression of disallow character
 */


function validateBadComma(text, badComma) {
  var baseIndex = 0;
  var tmpText = text;
  var result = [];

  while (tmpText) {
    if (badComma.test(tmpText)) {
      var index = tmpText.search(badComma) + baseIndex;
      result.push({
        valid: false,
        index: index
      });
      tmpText = tmpText.substr(index);
      baseIndex += index;
    } else {
      result.push({
        valid: true
      });
      break;
    }
  }

  return result;
}

;
module.exports = {
  linter: reporter,
  fixer: reporter
};
//# sourceMappingURL=textlint-rule-ja-use-comma-instead-of-touten.js.map